==========
fibermagic
==========

.. image:: https://img.shields.io/travis/Goreg12345/fibermagic.svg
        :target: https://travis-ci.org/Goreg12345/fibermagic

.. image:: https://img.shields.io/pypi/v/fibermagic.svg
        :target: https://pypi.python.org/pypi/fibermagic


Python package for Fiber Photometry Data Analysis

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!!) https://Goreg12345.github.io/fibermagic.

Features
--------

* TODO
